pub struct FullClearCharacterRequest {
pub username: String,
}Fields
username: StringTrait Implementations
Sourceimpl Clone for FullClearCharacterRequest
impl Clone for FullClearCharacterRequest
Sourcefn clone(&self) -> FullClearCharacterRequest
fn clone(&self) -> FullClearCharacterRequest
Returns a copy of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for FullClearCharacterRequest
impl Debug for FullClearCharacterRequest
Sourceimpl<'de> Deserialize<'de> for FullClearCharacterRequest
impl<'de> Deserialize<'de> for FullClearCharacterRequest
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl From<FullClearCharacterRequest> for JsValuewhere
FullClearCharacterRequest: Serialize,
impl From<FullClearCharacterRequest> for JsValuewhere
FullClearCharacterRequest: Serialize,
Sourcefn from(value: FullClearCharacterRequest) -> Self
fn from(value: FullClearCharacterRequest) -> Self
Converts to this type from the input type.
Sourceimpl FromWasmAbi for FullClearCharacterRequestwhere
Self: DeserializeOwned,
impl FromWasmAbi for FullClearCharacterRequestwhere
Self: DeserializeOwned,
Sourceimpl JsonSchema for FullClearCharacterRequest
impl JsonSchema for FullClearCharacterRequest
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
fn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl OptionFromWasmAbi for FullClearCharacterRequestwhere
Self: DeserializeOwned,
impl OptionFromWasmAbi for FullClearCharacterRequestwhere
Self: DeserializeOwned,
Sourceimpl OptionIntoWasmAbi for FullClearCharacterRequestwhere
FullClearCharacterRequest: Serialize,
impl OptionIntoWasmAbi for FullClearCharacterRequestwhere
FullClearCharacterRequest: Serialize,
Sourceimpl RefFromWasmAbi for FullClearCharacterRequestwhere
Self: DeserializeOwned,
impl RefFromWasmAbi for FullClearCharacterRequestwhere
Self: DeserializeOwned,
Sourcetype Abi = <JsType as RefFromWasmAbi>::Abi
type Abi = <JsType as RefFromWasmAbi>::Abi
The Wasm ABI type references to
Self are recovered from.Sourcetype Anchor = SelfOwner<FullClearCharacterRequest>
type Anchor = SelfOwner<FullClearCharacterRequest>
The type that holds the reference to
Self for the duration of the
invocation of the function that has an &Self parameter. This is
required to ensure that the lifetimes don’t persist beyond one function
call, and so that they remain anonymous.Sourceimpl Tsify for FullClearCharacterRequest
impl Tsify for FullClearCharacterRequest
Sourceimpl VectorFromWasmAbi for FullClearCharacterRequestwhere
Self: DeserializeOwned,
impl VectorFromWasmAbi for FullClearCharacterRequestwhere
Self: DeserializeOwned,
type Abi = <JsType as VectorFromWasmAbi>::Abi
unsafe fn vector_from_abi(js: Self::Abi) -> Box<[Self]>
Sourceimpl VectorIntoWasmAbi for FullClearCharacterRequestwhere
FullClearCharacterRequest: Serialize,
impl VectorIntoWasmAbi for FullClearCharacterRequestwhere
FullClearCharacterRequest: Serialize,
type Abi = <JsType as VectorIntoWasmAbi>::Abi
fn vector_into_abi(vector: Box<[Self]>) -> Self::Abi
Sourceimpl WasmDescribeVector for FullClearCharacterRequest
impl WasmDescribeVector for FullClearCharacterRequest
impl Eq for FullClearCharacterRequest
impl StructuralPartialEq for FullClearCharacterRequest