pub struct GetCharacterStateRequest {
pub character_id: Uuid,
}Fields
character_id: UuidTrait Implementations
Sourceimpl Clone for GetCharacterStateRequest
impl Clone for GetCharacterStateRequest
Sourcefn clone(&self) -> GetCharacterStateRequest
fn clone(&self) -> GetCharacterStateRequest
Returns a copy of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for GetCharacterStateRequest
impl Debug for GetCharacterStateRequest
Sourceimpl<'de> Deserialize<'de> for GetCharacterStateRequest
impl<'de> Deserialize<'de> for GetCharacterStateRequest
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl From<GetCharacterStateRequest> for JsValuewhere
GetCharacterStateRequest: Serialize,
impl From<GetCharacterStateRequest> for JsValuewhere
GetCharacterStateRequest: Serialize,
Sourcefn from(value: GetCharacterStateRequest) -> Self
fn from(value: GetCharacterStateRequest) -> Self
Converts to this type from the input type.
Sourceimpl FromWasmAbi for GetCharacterStateRequestwhere
Self: DeserializeOwned,
impl FromWasmAbi for GetCharacterStateRequestwhere
Self: DeserializeOwned,
Sourceimpl IntoWasmAbi for GetCharacterStateRequestwhere
GetCharacterStateRequest: Serialize,
impl IntoWasmAbi for GetCharacterStateRequestwhere
GetCharacterStateRequest: Serialize,
Sourceimpl JsonSchema for GetCharacterStateRequest
impl JsonSchema for GetCharacterStateRequest
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
fn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl OptionFromWasmAbi for GetCharacterStateRequestwhere
Self: DeserializeOwned,
impl OptionFromWasmAbi for GetCharacterStateRequestwhere
Self: DeserializeOwned,
Sourceimpl OptionIntoWasmAbi for GetCharacterStateRequestwhere
GetCharacterStateRequest: Serialize,
impl OptionIntoWasmAbi for GetCharacterStateRequestwhere
GetCharacterStateRequest: Serialize,
Sourceimpl PartialEq for GetCharacterStateRequest
impl PartialEq for GetCharacterStateRequest
Sourceimpl RefFromWasmAbi for GetCharacterStateRequestwhere
Self: DeserializeOwned,
impl RefFromWasmAbi for GetCharacterStateRequestwhere
Self: DeserializeOwned,
Sourcetype Abi = <JsType as RefFromWasmAbi>::Abi
type Abi = <JsType as RefFromWasmAbi>::Abi
The Wasm ABI type references to
Self are recovered from.Sourcetype Anchor = SelfOwner<GetCharacterStateRequest>
type Anchor = SelfOwner<GetCharacterStateRequest>
The type that holds the reference to
Self for the duration of the
invocation of the function that has an &Self parameter. This is
required to ensure that the lifetimes don’t persist beyond one function
call, and so that they remain anonymous.Sourceimpl Serialize for GetCharacterStateRequest
impl Serialize for GetCharacterStateRequest
Sourceimpl Tsify for GetCharacterStateRequest
impl Tsify for GetCharacterStateRequest
const DECL: &'static str = "export interface GetCharacterStateRequest {\n character_id: Uuid;\n}"
const SERIALIZATION_CONFIG: SerializationConfig
type JsType = JsType
fn into_js(&self) -> Result<Self::JsType, Error>where
Self: Serialize,
fn from_js<T>(js: T) -> Result<Self, Error>
Sourceimpl VectorFromWasmAbi for GetCharacterStateRequestwhere
Self: DeserializeOwned,
impl VectorFromWasmAbi for GetCharacterStateRequestwhere
Self: DeserializeOwned,
type Abi = <JsType as VectorFromWasmAbi>::Abi
unsafe fn vector_from_abi(js: Self::Abi) -> Box<[Self]>
Sourceimpl VectorIntoWasmAbi for GetCharacterStateRequestwhere
GetCharacterStateRequest: Serialize,
impl VectorIntoWasmAbi for GetCharacterStateRequestwhere
GetCharacterStateRequest: Serialize,
type Abi = <JsType as VectorIntoWasmAbi>::Abi
fn vector_into_abi(vector: Box<[Self]>) -> Self::Abi
Sourceimpl WasmDescribeVector for GetCharacterStateRequest
impl WasmDescribeVector for GetCharacterStateRequest
impl Eq for GetCharacterStateRequest
impl StructuralPartialEq for GetCharacterStateRequest